@@ -13,8 +13,11 @@ ln -s "$SRC_DIR" "$GOPATH/src/github.com/jesseduffield/lazygit"
 cd "$GOPATH/src/github.com/jesseduffield/lazygit"
 
 # build the project
-go get -v
-go build
+export CGO_ENABLED=0  # disable CGO, as there are no C libs to load
+LDFLAGS="-s -w"       # omit the symbol table / debug information and
+                      # DWARF symbol table.
+go get -v -ldflags "${LDFLAGS}"
+go build  -ldflags "${LDFLAGS}"
 
 # install the binary
 mkdir -p "$PREFIX/bin"
